import React from 'react';
import * as echarts from 'echarts';
import { EChartsOption, GeoOption, GridOption, LegendComponentOption, SeriesOption, TooltipOption, XAXisOption, YAXisOption } from 'echarts/types/dist/shared';
import './index.less';
export { default as ColorUtil } from './utils/color-util';
declare type ChartType = SeriesOption['type'];
declare type SmEChartsOption = {
    /**
     * @deprecated
     */
    legend?: LegendComponentOption | LegendComponentOption[];
    /**
     * @deprecated
     */
    grid?: GridOption | GridOption[];
    /**
     * @deprecated
     */
    xAxis?: XAXisOption | XAXisOption[];
    /**
     * @deprecated
     */
    yAxis?: YAXisOption | YAXisOption[];
    /**
     * @deprecated
     */
    geo?: GeoOption | GeoOption[];
    /**
     * @deprecated
     */
    series?: SeriesOption | SeriesOption[];
    /**
     * @deprecated
     */
    tooltip?: TooltipOption | TooltipOption[];
} & Omit<EChartsOption, 'legend' | 'grid' | 'xAxis' | 'yAxis' | 'geo' | 'series' | 'tooltip'>;
declare type EventHandler = ((arg: any) => void) | [string | Record<string, any>, (arg: any) => void];
declare type SmEChartsProps = {
    className?: string;
    style?: React.CSSProperties;
    notMerge?: boolean;
    lazyUpdate?: boolean;
    option?: SmEChartsOption;
    legend?: LegendComponentOption | LegendComponentOption[];
    grid?: GridOption | GridOption[];
    xAxis?: XAXisOption | XAXisOption[];
    yAxis?: YAXisOption | YAXisOption[];
    geo?: GeoOption | GeoOption[];
    series?: SeriesOption | SeriesOption[];
    tooltip?: TooltipOption | TooltipOption[];
    type?: ChartType | ChartType[];
    category?: any[];
    data?: any[];
    multi?: boolean;
    rotateAxis?: boolean;
    debug?: boolean;
    onEvents?: Record<string, EventHandler | EventHandler[]>;
};
export default class SmECharts extends React.Component<SmEChartsProps, any> {
    /**
     * 可以替换 echarts 版本
     */
    static echarts: typeof echarts;
    /**
     * 默认配置项
     */
    static defaultProps: {
        type: string;
        notMerge: boolean;
        lazyUpdate: boolean;
    };
    static defaultOption: {};
    static defaultAxis: {
        grid: {
            show: boolean;
            borderColor: string;
            borderWidth: number;
        };
        xAxis: {
            show: boolean;
            type: string;
        };
        yAxis: {
            show: boolean;
            type: string;
        };
    };
    private $root;
    private echartsInstance;
    constructor(props: SmEChartsProps);
    /**
     * 将 option 中特定项转成数组
     * @param option
     */
    transOptionItem2Array(option: EChartsOption): EChartsOption;
    getMergedSeries(): SeriesOption[];
    getMergedOption(): EChartsOption;
    setChartOption: any;
    handleWindowResize: any;
    unbindEvents: (props: SmEChartsProps) => void;
    bindEvens: () => void;
    componentDidMount(): void;
    componentDidUpdate(prevProps: SmEChartsProps): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
}
